@@ -1,13 +1,13 @@
 <?php
 /*
  * Copyright 2005 Randy Smith <perlstalker@gmail.com>
- * $Id: hooks.php,v 1.2 2005/10/05 14:32:37 randy Exp $
+ * $Id: hooks.php,v 1.3 2005/10/06 19:41:58 randy Exp $
  */
 
 if (!defined ('SM_PATH')) { define ('SM_PATH','../../'); }
 include_once(SM_PATH.'plugins/web_search/web_search.conf.php');
 
-global $engine, $adsense;
+global $engine, $adsense, $below_folder_list;
 
 function ws_menuline () {
   // set gettext domain
@@ -24,14 +24,26 @@ function ws_menuline () {
 
 function ws_left_main_before () {
   include_once (SM_PATH.'plugins/web_search/api.php');
-  global $engine;
-  mini_search();
+  include(SM_PATH.'plugins/web_search/web_search.conf.php');
+  if (!isset($below_folder_list)
+      || ! $below_folder_list) {
+    ws_left_main();
+  }
 }
 
 function ws_left_main_after () {
   include_once (SM_PATH.'plugins/web_search/api.php');
-  //  mini_search();
+  include(SM_PATH.'plugins/web_search/web_search.conf.php');
+  if (isset($below_folder_list)
+      && $below_folder_list) {
+    ws_left_main();
+  }
 }
 
+function ws_left_main () {
+  include_once (SM_PATH.'plugins/web_search/api.php');
+  global $engine;
+  mini_search();
+}
 
-?>
\ No newline at end of file
+?>
